@@ -1,4 +1,5 @@
 import os
+from turtle import width
 import xlwings as xw
 import glob
 
@@ -31,7 +32,7 @@ def load_toml_config() -> dict:
 
 
 def create_toml_config():
-    with open("export.toml", "w+") as f:
+    with open("export.toml", "w+", newline="\n", encoding="utf-8") as f:
         dump(CFG, f)
 
 
@@ -139,7 +140,7 @@ static func {func_name}(args=[]):
         if v
         else [],
         "dict": lambda v, n, id: eval(f'{{{v.replace("|",",")}}}') if v else {},
-        "function": lambda v, n, id: make_func(v, n, id) if v else "",
+        "function": lambda v, n, id: make_func(v or "pass", n, id),
     }
 
     # 表格数据脚本模板
@@ -193,7 +194,7 @@ static func {func_name}(args=[]):
 
     funcs = textwrap.dedent("\n".join(func_codes))
 
-    code = template.format(data=pprint.pformat(table, indent=2), funcs=funcs)
+    code = template.format(data=pprint.pformat(table, indent=2, width=10000000), funcs=funcs)
 
     project_root = CFG["settings"]["project_root"]
     relpath = os.path.relpath(output, project_root).replace("\\", "/")
@@ -204,7 +205,7 @@ static func {func_name}(args=[]):
             f"'{func_name}'", f"Function.new('res://{relpath}.gd','{func_name}')"
         )
 
-    with open(output + ".gd", "w+") as f:
+    with open(output + ".gd", "w+", newline="\n", encoding="utf-8") as f:
         f.write(code)
 
 
@@ -241,7 +242,7 @@ def completed_gd():
 
     code = code.format(refs_code=refs_code)
 
-    with open(settings_file_path, "w") as f:
+    with open(settings_file_path, "w", newline="\n", encoding="utf-8") as f:
         f.write(code)
 
 
